==> arv_2.6.2-3.tar.gz: arv-3/web/static/js/lang-en.js <==
Ext.i18n = {
    loading: 'Loading...',
    apply: 'Apply',
    ready: 'Ready',

    // add/remove button
    ok: "OK",
    add: "Add",
    remove: "Remove",
    modify: "Modify",

    //ok message
    message: 'Message',

    //info message
    info_rw_external_ip: "Roadwarrior doens't need external IP",

    // error message
    error_select_connect: 'Select a Connect first',
    error_select_node1: 'Select a Node 1 first',
    error_select_node2: 'Select a Node 2 first',
    error_select_cred: 'Select a credential first',
    error_select_tmplconnect: 'Select a TmplConnect first',
    error_select_tmplnode: 'Select a TmplNode first',
    error_select_tmpledge: 'Select a TmplEdge first',
    error_select_tmplvertex 'Select a TmplVertex first',
    error_select_node: 'Select a Node first',
    error_select_etab: 'Select an Etablissement first',
    error_select_extrip: 'Select an Extremity first',
    error_select_edge: "Select an Edge first",
    error_title: 'Error',
    info_title: 'Information',
    field_empty: 'Field should not be empty',
    row_not_selected: 'Select an item first',
    confirm_delete_title: 'Confirm',
    confirm_delete: 'Are you sure you want to delete this item?',
    delete_ok_title: 'Deleted',
    delete_ok: 'Item successfully deleted.',
    json_error: 'Unexpected return message',

    // login window
    login_title: 'Authentification',
    login_user: 'User',
    login_password: 'Password',

    // tmpl_node
    add_tmpl_node_title: 'Add new TmplNode',
    add_tmpl_node: 'New TmplNode name:',
    add_ok_title: 'TmplNode added',
    add_ok: 'New TmplNode successfully added',

    // tmpl_vertex
    tmplvertex_label: 'TmplVertex name',
    // window
    win_addtmpl_connect_title: 'Add new tmplConnect',
    win_addtmpl_edge_title: 'Add new tmplEdge',
    tmpl_connect_name: 'Name',
    save: 'Save',
    cancel: 'Cancel',
    exit: 'Exit',
    del_choice_button: 'Del',

	// Connect
	add_connect: 'Add connect',
    rw_dns: 'VPN DNS',

    // wizard
    previous: 'Previous',
    next: 'Next',
    dialog_submit: 'Sending data...',

    node: "Node",
    node1: "Node 1",
    tmplnode: "TmplNode",
    tmplnode1: "TmplNode 1",
    tmplnode2: "TmplNode 2",
    tmpl_node_mimetype: "Server type",
    node2: "Node 2",
    template: "Template",
    credential: 'Certificate',
    edge: "Edge",
    view: "View",
    errortitle: "Error",
    tmpl_connect: "TmplConnect",
    tmplvertex_name: "Name",
    tmplvertex1: "TmplVertex 1",
    tmplvertex2: "TmplVertex 2",
    tmplvertex_mimetype: "Type",
    tmplvertex_ip1: 'IP / Network',
    tmplvertex_ip2: 'IP / Netmask',
    tmpledges: "TmplEdges",
    addtmpledge_name: "Name",
    // add_node1
    addnode1_select_node_label: "Select a node type...",
    addnode1_tmplnode: "Choose a tmpl node",
    addnode_name: "Name",
    uai: "UAI",
    addnode1_title: 'Add new node',
    modify_node1_title: 'Modify the VPN server',
    addextremity_title: 'Add extremity',
    modextremity_title: 'Modify extremity',
    addextremity_pub_ip: 'Public IP',
    addextremity_priv_ip: 'Private IP',
    external_ip: 'external IP',
    send_db: 'Resend to Zéphir',
    sync_zephir: 'Get Zéphir infos node',
    addextremity_added: 'Extremity added',
    addextremity_msg: "New extremity successfully added",
    addnode1_zephir: "Imported from Zéphir",
    addnode1_manually: "Create manually",
    reload_tmplvertex: 'Reload template values',

    // zephir
    zephir_etab_libelle: 'Name',
    zephir_etab_uai: 'UAI',
    id_zephir: 'Zéphir ID',
    eole_version: 'Eole version',

    // add_node2
    addnode2_title: 'Add connect to',
    addnode2_tmplconnect: 'Choose a tmpl connect',
    addnode2_node: 'Choose a node',
    addnode2_choice_button: 'Add',
    modnode2_choice_button: 'Modify',
    addnode2_cred: 'Credential',
    addnode2_extr: 'Extremity',
    addnode2_ask: 'Please enter a credential name',
    addnode2_ask_title: 'Name',
    extrip_title: 'external IP',
    extrip_header: 'IP',
    //tmplvertex
    tmplvertex_title: "Vertex template",

    activate: '',
    // credentials
    cred_title: 'Credentials',
    addcred_title: 'Add new credential',
    modcred_title: 'Replace credential',
    cred: 'Credentials',
    cred_header: 'Credentials',
    ca: 'CA',
    cacert: 'Certification Authority',
    exp_date_title: 'Expiration date',
    delta: 'Expiration days',
    related_node: 'Related node',
    issuer: 'Issuer',
    addcred_private_key: 'Private key',
    addcred_public_key: 'Credential',
    addcred_passwd: 'Password',
    addcred_name: 'Name',
    generated_new_cred: 'Generate a new credential',
    imported_old_cred: 'Import a credential',
    imported_pkcs12_cred: 'Import a PKCS12 file',
    cred_request: 'Generate a credential request for CA',
    autosign_cred: 'Autosign public key',
    passwd: 'Choose Password',
    passwd2: 'Confirm Password',
    addcred_pkcs12: 'PKCS12 file',
    addcred_pkcs12_passwd: 'PKCS12 password',
    unmatched_passwd: 'Password are differents',
    //
    selectfile_upload: 'Select a file',
    selectcredential_label: 'Select a credential for ',

    certif_state: 'State',

    //tmplconnect
    addtmpl_connect_credauth: 'Select CA',
    addtmpl_connect_name: 'Name',
    //vertex
    vertex_added: 'Vertex added',
    addvertex_name: 'Name',
    vertex_mimetype: 'Type',
    vertex_mimetype_ip: 'IP',
    vertex_mimetype_network: 'Network',
    vertex_mimetype_range: 'Range',
    addvertex_ip_ip1: 'IP address',
    addvertex_range_ip1: 'Begin IP address',
    addvertex_range_ip2: 'End IP address',
    addvertex_network_ip1: 'Network IP address',
    addvertex_network_ip2: 'Netmask IP address',
    vertex_zephir_module: 'Zéphir Module',

    //leftsendcert
    leftsendcert: 'Certificate send',
    leftsendcert_always: 'Certificate sent ALWAYS via ipsec protocol',
    leftsendcert_never: 'Certificate sent NEVER via ipsec protocol',
    leftsendcert_always2: 'ALWAYS via ipsec protocol',
    leftsendcert_never2: 'NEVER via ipsec protocol',

    //fragmentation
    fragmentation: 'IKE fragmentation',
    fragmentation_no: 'Deactivate IKE fragmentation',
    fragmentation_yes: 'Activate IKE fragmentation',

    yes_msg: 'yes',
    no_msg: 'no',

    error_get_tmplnode: 'Cannot get Etablissement with "etablissement" has mimetype',

}

Ext.i18n.python = {
}

==> arv_2.10.0-3.tar.gz: arv-3/web/static/js/lang-en.js <==
Ext.i18n = {
    loading: 'Loading...',
    apply: 'Apply',
    ready: 'Ready',

    // add/remove button
    ok: "OK",
    add: "Add",
    remove: "Remove",
    modify: "Modify",

    //ok message
    message: 'Message',

    //info message
    info_rw_external_ip: "Roadwarrior doens't need external IP",

    // error message
    error_select_connect: 'Select a Connect first',
    error_select_node1: 'Select a Node 1 first',
    error_select_node2: 'Select a Node 2 first',
    error_select_cred: 'Select a credential first',
    error_select_tmplconnect: 'Select a TmplConnect first',
    error_select_tmplnode: 'Select a TmplNode first',
    error_select_tmpledge: 'Select a TmplEdge first',
    error_select_tmplvertex: 'Select a TmplVertex first',
    error_select_node: 'Select a Node first',
    error_select_etab: 'Select an Etablissement first',
    error_select_extrip: 'Select an Extremity first',
    error_select_edge: "Select an Edge first",
    error_title: 'Error',
    error_zephir_d: 'Zephir ID not available or already used',
    info_title: 'Information',
    field_empty: 'Field should not be empty',
    row_not_selected: 'Select an item first',
    confirm_delete_title: 'Confirm',
    confirm_delete: 'Are you sure you want to delete this item?',
    delete_ok_title: 'Deleted',
    delete_ok: 'Item successfully deleted.',
    json_error: 'Unexpected return message',

    // login window
    login_title: 'Authentification',
    login_user: 'User',
    login_password: 'Password',

    // tmpl_node
    add_tmpl_node_title: 'Add new TmplNode',
    add_tmpl_node: 'New TmplNode name:',
    add_ok_title: 'TmplNode added',
    add_ok: 'New TmplNode successfully added',

    // tmpl_vertex
    tmplvertex_label: 'TmplVertex name',
    // window
    win_addtmpl_connect_title: 'Add new tmplConnect',
    win_addtmpl_edge_title: 'Add new tmplEdge',
    tmpl_connect_name: 'Name',
    save: 'Save',
    cancel: 'Cancel',
    exit: 'Exit',
    del_choice_button: 'Del',

	// Connect
	add_connect: 'Add connect',
    rw_dns: 'VPN DNS',

    // wizard
    previous: 'Previous',
    next: 'Next',
    dialog_submit: 'Sending data...',

    node: "Node",
    node1: "Node 1",
    tmplnode: "TmplNode",
    tmplnode1: "TmplNode 1",
    tmplnode2: "TmplNode 2",
    tmpl_node_mimetype: "Server type",
    node2: "Node 2",
    template: "Template",
    credential: 'Certificate',
    edge: "Edge",
    view: "View",
    errortitle: "Error",
    tmpl_connect: "TmplConnect",
    tmplvertex_name: "Name",
    tmplvertex1: "TmplVertex 1",
    tmplvertex2: "TmplVertex 2",
    tmplvertex_mimetype: "Type",
    tmplvertex_ip1: 'IP / Network',
    tmplvertex_ip2: 'IP / Netmask',
    tmpledges: "TmplEdges",
    addtmpledge_name: "Name",
    // add_node1
    addnode1_select_node_label: "Select a node type...",
    addnode1_tmplnode: "Choose a tmpl node",
    addnode_name: "Name",
    uai: "UAI",
    addnode1_title: 'Add new node',
    modify_node1_title: 'Modify the VPN server',
    addextremity_title: 'Add extremity',
    modextremity_title: 'Modify extremity',
    addextremity_pub_ip: 'Public IP',
    addextremity_priv_ip: 'Private IP',
    external_ip: 'external IP',
    send_db: 'Resend to Zéphir',
    sync_zephir: 'Get Zéphir infos node',
    addextremity_added: 'Extremity added',
    addextremity_msg: "New extremity successfully added",
    addnode1_zephir: "Imported from Zéphir",
    addnode1_manually: "Create manually",
    reload_tmplvertex: 'Reload template values',

    // zephir
    zephir_etab_libelle: 'Name',
    zephir_etab_uai: 'UAI',
    id_zephir: 'Zéphir ID',
    eole_version: 'EOLE version',
    refresh: 'Refresh',
    // add_node2
    addnode2_title: 'Add connect to',
    addnode2_tmplconnect: 'Choose a tmpl connect',
    addnode2_node: 'Choose a node',
    addnode2_choice_button: 'Add',
    modnode2_choice_button: 'Modify',
    addnode2_cred: 'Credential',
    addnode2_extr: 'Extremity',
    addnode2_ask: 'Please enter a credential name',
    addnode2_ask_title: 'Name',
    extrip_title: 'external IP',
    extrip_header: 'IP',
    //tmplvertex
    tmplvertex_title: "Vertex template",

    activate: '',
    // credentials
    cred_title: 'Credentials',
    addcred_title: 'Add new credential',
    modcred_title: 'Replace credential',
    cred: 'Credentials',
    cred_header: 'Credentials',
    ca: 'CA',
    cacert: 'Certification Authority',
    exp_date_title: 'Expiration date',
    delta: 'Expiration days',
    related_node: 'Related node',
    issuer: 'Issuer',
    addcred_private_key: 'Private key',
    addcred_public_key: 'Credential',
    addcred_passwd: 'Password',
    addcred_name: 'Name',
    generated_new_cred: 'Generate a new credential',
    imported_old_cred: 'Import a credential',
    imported_pkcs12_cred: 'Import a PKCS12 file',
    cred_request: 'Generate a credential request for CA',
    autosign_cred: 'Autosign public key',
    passwd: 'Choose Password',
    passwd2: 'Confirm Password',
    addcred_pkcs12: 'PKCS12 file',
    addcred_pkcs12_passwd: 'PKCS12 password',
    nospace_certname: 'No space in certificate name allowed',
    tooshort_passwd: 'Password too short (> 3 chars.)',
    unmatched_passwd: 'Password are differents',
    //
    selectfile_upload: 'Select a file',
    selectcredential_label: 'Select a credential for ',

    certif_state: 'State',

    //tmplconnect
    addtmpl_connect_credauth: 'Select CA',
    addtmpl_connect_name: 'Name',
    //vertex
    vertex_added: 'Vertex added',
    addvertex_name: 'Name',
    vertex_mimetype: 'Type',
    vertex_mimetype_ip: 'IP',
    vertex_mimetype_network: 'Network',
    vertex_mimetype_range: 'Range',
    addvertex_ip_ip1: 'IP address',
    addvertex_range_ip1: 'Begin IP address',
    addvertex_range_ip2: 'End IP address',
    addvertex_network_ip1: 'Network IP address',
    addvertex_network_ip2: 'Netmask IP address',
    vertex_zephir_module: 'Zéphir Module',

    //leftsendcert
    leftsendcert: 'Certificate send',
    leftsendcert_always: 'Certificate sent ALWAYS via ipsec protocol',
    leftsendcert_never: 'Certificate sent NEVER via ipsec protocol',
    leftsendcert_always2: 'ALWAYS via ipsec protocol',
    leftsendcert_never2: 'NEVER via ipsec protocol',

    //fragmentation
    fragmentation: 'IKE fragmentation',
    fragmentation_no: 'Deactivate IKE fragmentation',
    fragmentation_yes: 'Activate IKE fragmentation',

    yes_msg: 'yes',
    no_msg: 'no',

    error_get_tmplnode: 'Cannot get Etablissement with "etablissement" has mimetype',

}

Ext.i18n.python = {
}
